function loadlevel(filename) --loads variables used for creating levels
	local file=love.filesystem.newFile(filename)
	file:open("r")

	--some random variables
	objectnum=1
	shapenum={}
	object={}
	shape={}
	shape_amount={}
	
	for line in file:lines() do --load data for objects
		local currentline=line
		object[objectnum]={x=0,y=0,kind=""}
		
		object[objectnum].x=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
		currentline=string.sub(currentline,string.find(currentline,",")+1)
		object[objectnum].y=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
		currentline=string.sub(currentline,string.find(currentline,",")+1)
		
		if string.find(currentline,",") then --check if line ends with object type
			object[objectnum].kind=string.sub(currentline,1,string.find(currentline,",")-1)
		else
			object[objectnum].kind=currentline
		end
		
		if object[objectnum].kind=="platform" then --load shape data for platforms
			shape[objectnum]={}
			shapenum=1
			while string.find(currentline,",") do
				shape[objectnum][shapenum]={x=0,y=0,width=0,height=0}
				
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				shape[objectnum][shapenum].x=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				shape[objectnum][shapenum].y=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				shape[objectnum][shapenum].width=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				
				if string.find(currentline,",") then	
					shape[objectnum][shapenum].height=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				else
					shape[objectnum][shapenum].height=tonumber(currentline)
				end
				
				shapenum=shapenum+1
			end
			shape_amount[objectnum]=shapenum-1
		end
		objectnum=objectnum+1
	end
	file:close()
end

function createlevel() --create physics stuff from loaded level data
	--more random variables
	anchor={} --static bodies
	platform={} --dynamic bodies
	platform_active={} --for allowing one platform to be controlled at a time
	platform_shape={} --obvious
	joint={} --revolute joints connecting anchors and platforms
	wall={} --uninteractive walls
	wall_shape={} --what else?
	spike={} --balls + spikes =/= a good thing :P
	spike_shape={} --I'm going to stop now

	world=love.physics.newWorld(love.graphics.getWidth(),love.graphics.getHeight())
	world:setGravity(0,500)

	local a, b
	for a=1,objectnum-1 do
		if object[a].kind=="ball" then --create ball
			ball=love.physics.newBody(world,object[a].x,object[a].y)
			ball_shape=love.physics.newCircleShape(ball,0,0,16)
			ball:setMassFromShapes()
			ball_shape:setData("ball")
			ball_shape:setCategory(2)
		end
		
		if object[a].kind=="goal" then --create goal
			goal=love.physics.newBody(world,object[a].x,object[a].y)
			goal_shape=love.physics.newRectangleShape(goal,0,0,32,32)
			goal_shape:setData("goal")
		end
		
		if object[a].kind=="wall" then --create wall
			wall[a]=love.physics.newBody(world,object[a].x,object[a].y)
			wall_shape[a]=love.physics.newRectangleShape(wall[a],0,0,32,32)
		end
		
		if object[a].kind=="spike" then --create spikeball
			spike[a]=love.physics.newBody(world,object[a].x,object[a].y)
			spike_shape[a]=love.physics.newCircleShape(spike[a],0,0,16)
			spike_shape[a]:setData("spike")
		end
		
		if object[a].kind=="platform" then --create plaforms
			anchor[a]=love.physics.newBody(world,object[a].x,object[a].y)
			
			platform_active[a]=0
			platform_shape[a]={}
			platform[a]=love.physics.newBody(world,object[a].x,object[a].y,1,0)
			for b=1,shape_amount[a] do --attach shapes to platforms
				platform_shape[a][b]=love.physics.newRectangleShape(platform[a],shape[a][b].x,shape[a][b].y,shape[a][b].width,shape[a][b].height)
				platform_shape[a][b]:setData("platform"..tostring(a))
				platform_shape[a][b]:setRestitution(0)
				platform_shape[a][b]:setMask(1)
			end
			platform[a]:setBullet(true)
			
			joint[a]=love.physics.newRevoluteJoint(anchor[a],platform[a],object[a].x,object[a].y)
		end
	end
end